/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Preferences UI System.
 *
 * The Initial Developer of the Original Code is
 * Ben Goodger.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Ben Goodger <ben@mozilla.org>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");

prefwindow {
  padding: 0;
  font: -moz-dialog !important;
}

prefpane {
  padding: 12px 12px 0 12px;
}

prefwindow[type="child"] > prefpane {
  padding: 0;
}

.prefWindow-dlgbuttons {
  margin: 0 12px 8px;
  padding-top: 0 !important;
}

.paneSelector {
  font: message-box;
  padding: 1px 4px;
  -moz-appearance: toolbar;
  margin: 0;
}

radio[pane] {
  border: solid transparent;
  border-width: 0 2px;
  padding: 5px 4px 3px;
  margin: 0;
  -moz-appearance: none;
  text-shadow: rgba(255, 255, 255, 0.4) 0 1px;
}

radio[pane]:active:hover {
  text-shadow: none;
}

radio[pane] > .paneButtonIcon {
  /* preload external filter file */
  background-image: url("chrome://global/skin/filters.svg");
}

radio[pane]:active:hover > .paneButtonIcon {
  filter: url("chrome://global/skin/filters.svg#iconPressed");
}

radio[pane][selected="true"] {
  -moz-border-image: url("chrome://global/skin/icons/panebutton-active.png") 0 2 repeat stretch;
}

radio[pane][selected="true"]:-moz-window-inactive {
  -moz-border-image: url("chrome://global/skin/icons/panebutton-inactive.png") 0 2 repeat stretch;
}

.paneButtonLabel {
  margin: 0 !important;
}
